# GliNERBridge

`GliNERBridge` is a task-generic bridge coordinating task GliNER2 execution for arbitrary tasks, leveraging GliNER2's
well-defined execution modes.

---

::: sieves.tasks.predictive.gliner_bridge.GliNERBridge
